# De:code

[![PyPI](https://img.shields.io/pypi/v/decode.svg?label=PyPI&style=flat-square)](https://pypi.org/pypi/decode/)
[![Python](https://img.shields.io/pypi/pyversions/decode.svg?label=Python&color=yellow&style=flat-square)](https://pypi.org/pypi/decode/)
[![Test](https://img.shields.io/github/workflow/status/deshima-dev/decode/Test?logo=github&label=Test&style=flat-square)](https://github.com/deshima-dev/decode/actions)
[![License](https://img.shields.io/badge/license-MIT-blue.svg?label=License&style=flat-square)](LICENSE)
[![DOI](https://img.shields.io/badge/DOI-10.5281/zenodo.3384216-blue?style=flat-square)](https://doi.org/10.5281/zenodo.3384216)

DESHIMA code for data analysis

## Installation

```shell
$ pip install decode
```
